ReverseServerState

Struct ReverseServerState 

pub struct ReverseServerState {
    pub active_control: AtomicU32,
    pub active_streams: AtomicU32,
    pub pending_external: AtomicU32,
    pub denied_bind: AtomicU32,
    pub dropped_stream_limit: AtomicU32,
    pub dropped_pending_limit: AtomicU32,
}
Active state of the reverse server, exposed for tests and admin hooks.

Fields

active_control: AtomicU32

Number of currently-active (accepted, awaiting use) control connections.

active_streams: AtomicU32

Number of currently-active external streams being relayed.

pending_external: AtomicU32

Number of external clients waiting for a control connection.

denied_bind: AtomicU32

Number of listeners denied because of allow_bind.

dropped_stream_limit: AtomicU32

Number of streams dropped because max_streams_per_listener was reached.

dropped_pending_limit: AtomicU32

Number of external clients dropped because max_pending_external was reached.

Implementations

Source

impl ReverseServerState

pub fn snapshot(&self) -> ReverseServerStateSnapshot

Snapshot of the counters for admin/log display.