pub struct ControlStream {
pub stream: TcpStream,
pub peer_addr: SocketAddr,
pub redacted_auth: Option<String>,
}Expand description
A control stream paired with metadata, used when handing the stream off from the auth phase to the relay phase.
Fields
stream: TcpStreampeer_addr: SocketAddrredacted_auth: Option<String>Auto Trait Implementations
impl !Freeze for ControlStream
impl RefUnwindSafe for ControlStream
impl Send for ControlStream
impl Sync for ControlStream
impl Unpin for ControlStream
impl UnsafeUnpin for ControlStream
impl UnwindSafe for ControlStream